Sync available ruv programs to your computer

TODO: Better readme

# Uploading a new version

1. Set a new version in setup.py
2. Run `. ./prepare_upload.sh` (this is assuming you have lastpass.
    Optional if you want to type your pypi credentials manually).
3. Run `make upload`